<?php

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Component\Display;
use EventPortal\Domain\Component\Input\Text;
use EventPortal\Domain\Component\Scope;
use EventPortal\Domain\Component\Section;
use EventPortal\Domain\Form\Facades\Form;
use EventPortal\Domain\Handlers\FindOrCreateModel;
use EventPortal\Domain\Handlers\UpdateModel;
use EventPortal\Domain\Speaker\Handlers\CreateSpeaker;
use EventPortal\Domain\Speaker\Handlers\UpdateSpeaker;
use EventPortal\Domain\Speaker\Models\Speaker;
use EventPortal\Domain\User\Models\User;
use EventPortal\Enums\InertiaMethod;
use Illuminate\Validation\Rule;

Form::make('speaker.create')
    ->addHandler(FindOrCreateModel::class)
    ->addHandler(CreateSpeaker::class)
    ->addFields(static function () {
        return [
            Section::make()->fields([
                Text::make('First name')
                    ->rules([
                        'required',
                        'string',
                        'min:2',
                        'max:255',
                    ])
                    ->placeholder('Jane'),
                Text::make('Last name')
                    ->rules([
                        'required',
                        'string',
                        'min:2',
                        'max:255',
                    ])
                    ->placeholder('Doe'),
                Text::make('Email address')
                    ->name('email')
                    ->rules([
                        'required',
                        'email',
                        'max:255',
                    ])
                    ->placeholder('jane.doe@example.com'),
            ]),
        ];
    })
    ->addActions(static function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.index'),
        ];
    })
    ->addPrimaryAction(function () {
        return Button::make('Create speaker')
            ->method(InertiaMethod::POST())
            ->route('admin.speaker.store');
    });

Form::make('speaker.show')
    ->addFields(static function () {
        return [
            Section::make()->fields([
                Display::make('First name')->scopeTo('user'),
                Display::make('Last name')->scopeTo('user'),
                Display::make('Email')->scopeTo('user'),
            ]),
        ];
    })
    ->addActions(static function (Speaker $speaker) {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.index'),
            Button::make('Edit speaker')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.edit', ['speaker' => $speaker]),
        ];
    });

Form::make('speaker.edit')
    ->addHandler(UpdateModel::class)
    ->addHandler(UpdateSpeaker::class)
    ->addFields(static function (User $user) {
        return [
            Section::make()->fields([
                Scope::make('user')->fields([
                    Text::make('First name')
                        ->rules([
                            'required',
                            'string',
                            'min:2',
                            'max:255',
                        ])
                        ->placeholder('Jane'),
                    Text::make('Last name')
                        ->rules([
                            'required',
                            'string',
                            'min:2',
                            'max:255',
                        ])
                        ->placeholder('Doe'),
                    Text::make('Email address')
                        ->name('email')
                        ->rules([
                            'required',
                            'email',
                            'max:255',
                            Rule::unique('users', 'email')->ignore($user->id),
                        ])
                        ->placeholder('jane.doe@example.com'),
                ]),
            ]),
        ];
    })
    ->addActions(static function () {
        return [
            Button::make('Cancel')
                ->variant('secondary')
                ->method(InertiaMethod::VISIT())
                ->route('admin.speaker.index'),
        ];
    })
    ->addPrimaryAction(function (Speaker $speaker) {
        return Button::make('Update speaker')
            ->method(InertiaMethod::POST())
            ->route('admin.speaker.update', ['speaker' => $speaker]);
    });
