<?php

namespace EventPortal\Domain\Template\Models;

use EventPortal\Contracts\Event;
use EventPortal\Domain\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Support\Arr;

class Template extends Model
{
    public const KEY = 'template';

    /** @var array[string] */
    public $fillable = [
        'name',
        'areas',
    ];

    /** @var array[string] */
    public $casts = [
        'areas' => 'json',
    ];

    public function event(): BelongsTo
    {
        return $this->belongsTo(Event::class);
    }

    public function addArea(string $name, array $data): void
    {
        $currentData = $this->areas ?? [];

        $newData = array_merge($currentData, [
            $name => $data,
        ]);

        $this->update(['areas' => $newData]);
    }

    /**
     * @return array|string|null
     */
    public function getArea(string $name)
    {
        return Arr::get($this->areas, $name);
    }
}
