<?php

namespace EventPortal\Domain\Util\Statistics;

use Illuminate\Database\Eloquent\Model;

class Statistics
{
    /** @var \Illuminate\Support\Collection */
    private $stats;

    /** @var array */
    private $context = [];

    public function __construct()
    {
        $this->stats = collect();
    }

    public static function make(): self
    {
        return new self;
    }

    public function context(Model ...$models): self
    {
        foreach ($models as $model) {
            $this->context[$model::KEY] = $model;
        }

        return $this;
    }

    public function add(callable $callable): self
    {
        $this->stats->push($callable);

        return $this;
    }

    public function get(): array
    {
        return $this
            ->stats
            ->flatMap(function (callable $callable) {
                return app()->call($callable, $this->context);
            })
            ->map(function (Stat $stat) {
                return $stat->asArray();
            })
            ->values()
            ->toArray();
    }
}
