<?php

namespace EventPortal\Tests\Feature\Admin\Template;

use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Template\Areas\EventArea;
use EventPortal\Domain\Template\Models\Template;
use EventPortal\Tests\Support\Traits\SeedRolesAndPermissions;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class CreateTemplateFromEventTest extends TestCase
{
    use RefreshDatabase, SeedRolesAndPermissions;

    /** @test **/
    public function creates_template_from_event()
    {
        $event = factory(Event::class)->create([
            'snippet' => 'Small snippet about the event',
        ]);

        $this
            ->actingAsSuperAdmin()
            ->post(
                route('admin.template.store', ['event' => $event->id]),
                [
                    'name' => 'Template A',
                ]
            )
            ->assertRedirect(route('admin.event.index'));

        $template = Template::first();

        $expectedAreas = [
            EventArea::class => [
                'snippet' => 'Small snippet about the event',
                'description' => null,
                'is_virtual' => '',
                'broadcast_type' => null,
                'broadcast_url' => null,
                'email' => null,
            ],
        ];

        $this->assertEquals('Template A', $template->name);
        $this->assertEquals($expectedAreas, $template->areas);
    }
}
