<?php

namespace EventPortal\Tests\Unit\Template\Areas;

use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Template\Areas\EmailArea;
use EventPortal\Enums\EmailType;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EmailAreaTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_turn_model_into_array(): void
    {
        $event = factory(Event::class)->create();

        factory(EventEmail::class)->create([
            'event_id' => $event->id,
            'type' => EmailType::invite(),
            'subject' => 'You have been invited',
            'reply_to_address' => 'reply@example.com',
        ]);

        $actual = (new EmailArea())->fromModel($event);

        $expected = [
            [
                'type' => EmailType::invite(),
                'subject' => 'You have been invited',
                'reply_to_address' => 'reply@example.com',

            ],
        ];

        $this->assertEquals($expected, $actual);
    }

    /** @test **/
    public function can_turn_array_into_model(): void
    {
        $event = factory(Event::class)->create();

        $actual = (new EmailArea())->toModel($event, [
            [
                'type' => EmailType::invite(),
                'subject' => 'You have been invited',
                'reply_to_address' => 'reply@example.com',
            ],
            [
                'type' => EmailType::joiningInstructions(),
                'subject' => 'These are you joining instructions',
                'reply_to_address' => 'reply@example.com',
            ],
        ]);

        $first = head($actual);

        $this->assertEquals(EmailType::invite(), $first->type);
        $this->assertEquals('You have been invited', $first->subject);
        $this->assertEquals('reply@example.com', $first->reply_to_address);

        $last = last($actual);

        $this->assertEquals(EmailType::joiningInstructions(), $last->type);
        $this->assertEquals('These are you joining instructions', $last->subject);
        $this->assertEquals('reply@example.com', $last->reply_to_address);
    }
}
