<?php

namespace EventPortal\Tests\Unit\Template\Areas;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Template\Contracts\FormAreaContract;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EventAreaTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_turn_model_into_array(): void
    {
        $event = factory(Event::class)->create([
            'snippet' => 'This is a snippet',
            'description' => 'This is a description',
            'email' => 'email@example.com',
        ]);

        $actual = resolve(FormAreaContract::class)->fromModel($event);

        $expected = [
            'snippet' => 'This is a snippet',
            'description' => 'This is a description',
            'is_virtual' => false,
            'broadcast_url' => null,
            'email' => 'email@example.com',
        ];

        $this->assertEquals($expected, $actual);
    }

    /** @test **/
    public function can_turn_array_into_model(): void
    {
        $actual = resolve(FormAreaContract::class)->toModel([
            'snippet' => 'This is a snippet',
            'description' => 'This is a description',
            'is_virtual' => Option::make('No')->value(0),
            'broadcast_url' => null,
            'email' => 'email@example.com',
        ]);

        $this->assertInstanceOf(Event::class, $actual);

        $this->assertEquals('This is a snippet', $actual->snippet);
        $this->assertEquals('This is a description', $actual->description);
        $this->assertEquals('email@example.com', $actual->email);
        $this->assertFalse($actual->is_virtual);
        $this->assertNull($actual->broadcast_url);
    }
}
