<?php

namespace EventPortal\Tests\Unit\Template\Handlers;

use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Form\Payload;
use EventPortal\Domain\Template\Areas\EmailArea;
use EventPortal\Domain\Template\Handlers\StoreTemplate;
use EventPortal\Domain\Template\Models\Template;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;
use Illuminate\Pipeline\Pipeline;

class StoreTemplateTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_store_event_as_template(): void
    {
        $event = factory(Event::class)->create();

        $payload = Payload::make(['name' => 'Template One'])->withModel($event);

        app(Pipeline::class)
            ->send($payload)
            ->through([new StoreTemplate()])
            ->thenReturn();

        $this->assertDatabaseHas('templates', [
            'name' => 'Template One',
        ]);
    }

    /** @test **/
    public function can_store_template_with_emails(): void
    {
        $event = factory(Event::class)->create();
        factory(EventEmail::class)->create(['event_id' => $event->id]);
        factory(EventEmail::class)->state('joining-instructions')->create(['event_id' => $event->id]);

        $payload = Payload::make([
            'name' => 'Template One',
            'areas' => [
                [
                    'label' => 'Emails',
                    'value' => EmailArea::class,
                ],
            ],
        ])->withModel($event);

        app(Pipeline::class)
            ->send($payload)
            ->through([new StoreTemplate()])
            ->thenReturn();

        $expected = [
            [
                'type' => 'Invite',
                'subject' => 'Your invitation',
                'reply_to_address' => 'reply@example.com',
            ],
            [
                'type' => 'Joining Instructions',
                'subject' => 'Your joining instructions',
                'reply_to_address' => 'reply@example.com',
            ],
        ];

        $this->assertEquals($expected, Template::first()->areas[EmailArea::class]);

        $this->assertTemplateExists('Template One');
    }
}
