<?php

namespace EventPortal\Tests\Unit\Template\Models;

use EventPortal\Domain\Template\Models\Template;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class TemplateTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_add_area(): void
    {
        $template = factory(Template::class)->create();

        $template->addArea('TestArea', [
            'title' => 'The Title',
        ]);

        $expected = [
            'TestArea' => [
                'title' => 'The Title',
            ],
        ];

        $this->assertEquals($expected, $template->areas);
    }

    /** @test **/
    public function can_add_multiple_areas(): void
    {
        $template = factory(Template::class)->create();

        $template->addArea('TestAreaA', [
            'title' => 'The Title A',
        ]);

        $template->addArea('TestAreaB', [
            'title' => 'The Title B',
        ]);

        $expected = [
            'TestAreaA' => [
                'title' => 'The Title A',
            ],
            'TestAreaB' => [
                'title' => 'The Title B',
            ],
        ];

        $this->assertEquals($expected, $template->areas);
    }

    /** @test **/
    public function can_get_area(): void
    {
        $template = factory(Template::class)->create([
            'areas' => [
                'TestAreaA' => [
                    'title' => 'The Title A',
                ],
                'TestAreaB' => [
                    'title' => 'The Title B',
                ],
                'TestAreaC' => [
                    'title' => 'The Title C',
                ],
            ],
        ]);

        $this->assertEquals(['title' => 'The Title B'], $template->getArea('TestAreaB'));
    }
}
